@@ -171,13 +171,13 @@ struct ksba_certreq_s;
 typedef struct ksba_certreq_s *ksba_certreq_t;
 typedef struct ksba_certreq_s *KsbaCertreq _KSBA_DEPRECATED;
 
-/* This is a reader object vor various purposes
+/* This is a reader object for various purposes
    see ksba_reader_new et al. */
 struct ksba_reader_s;
 typedef struct ksba_reader_s *ksba_reader_t;
 typedef struct ksba_reader_s *KsbaReader _KSBA_DEPRECATED;
 
-/* This is a writer object vor various purposes
+/* This is a writer object for various purposes
    see ksba_writer_new et al. */
 struct ksba_writer_s;
 typedef struct ksba_writer_s *ksba_writer_t;
@@ -189,7 +189,7 @@ struct ksba_asn_tree_s;
 typedef struct ksba_asn_tree_s *ksba_asn_tree_t;
 typedef struct ksba_asn_tree_s *KsbaAsnTree _KSBA_DEPRECATED;
 
-/* This is an object to reference an General Name.  Such an object is
+/* This is an object to reference a General Name.  Such an object is
    returned by several functions. */
 struct ksba_name_s;
 typedef struct ksba_name_s *ksba_name_t;
@@ -343,8 +343,8 @@ gpg_error_t ksba_crl_get_auth_key_id (ksba_crl_t crl,
                                       ksba_sexp_t *r_serial);
 gpg_error_t ksba_crl_get_crl_number (ksba_crl_t crl, ksba_sexp_t *number);
 gpg_error_t ksba_crl_get_update_times (ksba_crl_t crl,
-                                       ksba_isotime_t this,
-                                       ksba_isotime_t next);
+                                       ksba_isotime_t this_update,
+                                       ksba_isotime_t next_update);
 gpg_error_t ksba_crl_get_item (ksba_crl_t crl,
                                ksba_sexp_t *r_serial,
                                ksba_isotime_t r_revocation_date,
